package Egg::Appli::note;
use strict;
use warnings;

our $VERSION= '0.01';

1;

__END__

=head1 NAME

Egg::Appli::note - note.

=head1 DESCRIPTION

This directory is for the arrangement of the application module.

=head1 SEE ALSO

L<Egg::Appli>,
L<Egg::Plugin::Appli>,
L<Egg::Release>,

=head1 AUTHOR

Masatoshi Mizuno, E<lt>mizunoE<64>bomcity.comE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright (C) 2006 Bee Flag, Corp. E<lt>L<http://egg.bomcity.com/>E<gt>, All Rights Reserved.

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself, either Perl version 5.8.6 or,
at your option, any later version of Perl 5 you may have available.

=cut
