package Egg::Model;
#
# Copyright 2006 Bee Flag, Corp. All Rights Reserved.
# Masatoshi Mizuno E<lt>mizunoE<64>bomcity.comE<gt>
#
# $Id: Model.pm 34 2006-12-14 08:17:52Z lushe $
#
use strict;
use warnings;
use base qw/Egg::Config/;

our $VERSION= '0.02';

1;

__END__


=head1 NAME

Egg::Model - Common package for MODEL module.

=head1 SYNOPSIS

 package Egg::Model::[Foo];
 use strict;
 use base qw/Egg::Model/;
 
 ... ban, bo, bo, bon.

=head1 DESCRIPTION

There is nothing now, too.

=head1 SEE ALSO

L<Egg::Release>, L<Egg::Config>

=head1 AUTHOR

Masatoshi Mizuno, E<lt>mizunoE<64>bomcity.comE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright (C) 2006 Bee Flag, Corp. E<lt>L<http://egg.bomcity.com/>E<gt>, All Rights Reserved.

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself, either Perl version 5.8.6 or,
at your option, any later version of Perl 5 you may have available.

=cut
